# Generated by roxygen2: do not edit by hand

export(ARRAY_to_MM)
export(ARRAY_to_RSDA)
export(ARRAY_to_iGAP)
export(MM_to_ARRAY)
export(MM_to_RSDA)
export(MM_to_iGAP)
export(RSDA_format)
export(RSDA_to_ARRAY)
export(RSDA_to_MM)
export(RSDA_to_iGAP)
export(SODAS_to_ARRAY)
export(SODAS_to_MM)
export(SODAS_to_iGAP)
export(aggregate_to_symbolic)
export(check_zero_width_intervals)
export(clean_colnames)
export(hist_cor)
export(hist_cov)
export(hist_mean)
export(hist_var)
export(iGAP_to_ARRAY)
export(iGAP_to_MM)
export(iGAP_to_RSDA)
export(int_center)
export(int_containment)
export(int_convert_format)
export(int_cor)
export(int_cosine)
export(int_cov)
export(int_cv)
export(int_detect_format)
export(int_dice)
export(int_dispersion)
export(int_dist)
export(int_dist_all)
export(int_dist_matrix)
export(int_entropy)
export(int_granularity)
export(int_imprecision)
export(int_information_content)
export(int_iqr)
export(int_jaccard)
export(int_kurtosis)
export(int_list_conversions)
export(int_mad)
export(int_mean)
export(int_median)
export(int_midrange)
export(int_mode)
export(int_overlap)
export(int_overlap_coefficient)
export(int_pairwise_dist)
export(int_quantile)
export(int_radius)
export(int_range)
export(int_similarity_matrix)
export(int_skewness)
export(int_symmetry)
export(int_tailedness)
export(int_tanimoto)
export(int_trimmed_mean)
export(int_trimmed_var)
export(int_uniformity)
export(int_var)
export(int_width)
export(int_winsorized_mean)
export(int_winsorized_var)
export(read_symbolic_csv)
export(search_data)
export(set_variable_format)
export(to_all_interval_formats)
export(write_symbolic_csv)
import(HistDAWass)
importFrom(RSDA,SODAS.to.RSDA)
importFrom(dplyr,select)
importFrom(graphics,hist)
importFrom(magrittr,"%>%")
importFrom(methods,new)
importFrom(stats,as.dist)
importFrom(stats,complete.cases)
importFrom(stats,cov)
importFrom(stats,cutree)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,kmeans)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(tidyr,separate)
importFrom(tidyr,unite)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,read.table)
importFrom(utils,write.table)
