% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{ohtemp.int}
\alias{ohtemp.int}
\title{Ohio River Basin 30-Year Trimmed Mean Daily Temperatures Interval Dataset}
\format{
A data frame with 161 rows and 7 variables:
\itemize{
    \item \code{ID}: Global Historical Climatological Network (GHCN) station identifier.
    \item \code{NAME}: GHCN station name.
    \item \code{STATE}: Two-digit state designation.
    \item \code{LATITUDE}: Latitude coordinate position.
    \item \code{LONGITUDE}: Longitude coordinate position.
    \item \code{ELEVATION}: Elevation of the measurement location (meters).
    \item \code{TEMPERATURE}: 30-year mean daily temperature (tenths of degrees Celsius).
}
}
\source{
\url{https://CRAN.R-project.org/package=intkrige}
}
\usage{
data(ohtemp.int)
}
\description{
Interval-valued dataset of 30-year trimmed mean daily temperatures for the
Ohio river basin. Intervals are defined by the mean daily maximum and minimum
temperatures from January 1, 1988 to December 31, 2018.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 161 \cr
  \strong{Variables (p)} \tab 7 \cr
  \strong{Subject area} \tab Climate \cr
  \strong{Symbolic format} \tab Interval \cr
  \strong{Analytical tasks} \tab Regression, Spatial analysis
}
}

\examples{
data(ohtemp.int)
}
\keyword{datasets}
\keyword{interval}
