% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{energy_consumption.distr}
\alias{energy_consumption.distr}
\title{US Energy Consumption Distribution-Valued Dataset}
\format{
A data frame with 5 observations and 3 variables:
\itemize{
    \item \code{type}: Energy type.
    \item \code{mean}: Mean consumption across 50 states.
    \item \code{sd}: Standard deviation.
}
}
\usage{
data(energy_consumption.distr)
}
\description{
Distribution-valued dataset of energy consumption across US states.
Each energy type described by Normal distribution parameters (mean, SD).
}
\details{
Five types: Petroleum, Natural Gas, Coal, Hydroelectric, Nuclear Power.
Values are rescaled consumption from the US Census Bureau (2004).
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 5 \cr
  \strong{Variables (p)} \tab 3 \cr
  \strong{Subject area} \tab Energy \cr
  \strong{Symbolic format} \tab Distribution \cr
  \strong{Analytical tasks} \tab Descriptive statistics
}
}

\examples{
data(energy_consumption.distr)
}
\references{
Billard, L. and Diday, E. (2006). \emph{Symbolic Data Analysis}. Wiley.
Table 2.8.
}
\keyword{datasets}
\keyword{distribution}
