% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{prostate.int}
\alias{prostate.int}
\title{Prostate Cancer Clinical Interval Dataset}
\format{
A data frame with 97 observations and 9 interval-valued variables:
\itemize{
    \item \code{lcavol}: Log cancer volume range.
    \item \code{lweight}: Log prostate weight range.
    \item \code{age}: Patient age range.
    \item \code{lbph}: Log benign prostatic hyperplasia amount range.
    \item \code{svi}: Seminal vesicle invasion range.
    \item \code{lcp}: Log capsular penetration range.
    \item \code{gleason}: Gleason score range.
    \item \code{pgg45}: Percentage Gleason scores 4 or 5 range.
    \item \code{lpsa}: Log prostate specific antigen range.
}
}
\source{
Extracted from RSDA package (\code{int_prost_train}, \code{int_prost_test}).
}
\usage{
data(prostate.int)
}
\description{
Interval-valued clinical measurements for 97 prostate cancer patients
(training and test sets combined). Contains 9 interval-valued variables
from log-transformed cancer volume, weight, age, and other clinical
predictors.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 97 \cr
  \strong{Variables (p)} \tab 9 \cr
  \strong{Subject area} \tab Medical \cr
  \strong{Symbolic format} \tab Interval \cr
  \strong{Analytical tasks} \tab Regression
}
}

\examples{
data(prostate.int)
}
\references{
Stamey, T. et al. (1989). Prostate specific antigen in the diagnosis and
treatment of adenocarcinoma of the prostate. II. Radical prostatectomy
treated patients. \emph{J. Urology}, 141(5), 1076-1083.
}
\keyword{datasets}
\keyword{interval}
\keyword{medical}
