% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{water_flow.int}
\alias{water_flow.int}
\title{Water Flow Sensor Readings Interval Dataset}
\format{
A data frame with 316 observations and 48 variables:
\itemize{
    \item \code{if1} through \code{if48} (excluding \code{if17}): 47 interval-valued
          sensor feature measurements.
    \item \code{class}: Group label (1 or 2).
}
}
\source{
\url{https://github.com/Natandradesa/Kernel-Clustering-for-Interval-Data}
}
\usage{
data(water_flow.int)
}
\description{
Large interval-valued dataset of water flow sensor readings with 316
observations and 47 interval-valued feature variables (IF1-IF48, excluding
IF17), classified into 2 groups. Used as a benchmark for interval data
clustering with high-dimensional features.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 316 \cr
  \strong{Variables (p)} \tab 48 \cr
  \strong{Subject area} \tab Engineering \cr
  \strong{Symbolic format} \tab Interval \cr
  \strong{Analytical tasks} \tab Clustering
}
}

\examples{
data(water_flow.int)
}
\references{
Andrade, N. A., de Carvalho, F. A. T. and Pimentel, B. A. (2025).
Kernel clustering with automatic variable weighting for interval data.
\emph{Neurocomputing}, 617, 128954.
}
\keyword{clustering}
\keyword{datasets}
\keyword{interval}
