% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{exchange_rate_returns.hist}
\alias{exchange_rate_returns.hist}
\title{Exchange Rate Returns Histogram Time Series}
\format{
A data frame with 108 observations and 1 histogram-valued
variable:
\itemize{
    \item \code{returns}: Histogram of daily exchange rate returns
    within each month.
}
}
\source{
HistDAWass R package (\code{RetHTS} dataset).
}
\usage{
data(exchange_rate_returns.hist)
}
\description{
Histogram-valued time series of 108 monthly observations of daily
exchange rate returns. Each observation is a histogram distribution
of intra-month daily returns.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 108 \cr
  \strong{Variables (p)} \tab 1 \cr
  \strong{Subject area} \tab Finance \cr
  \strong{Symbolic format} \tab Histogram \cr
  \strong{Analytical tasks} \tab Time series, Descriptive statistics
}
}

\examples{
data(exchange_rate_returns.hist)
}
\references{
Irpino, A. and Verde, R. (2015). Basic statistics for distributional
symbolic variables: a new metric-based approach. \emph{Advances in
Data Analysis and Classification}, 9(2), 143--175.

Original data from the HistDAWass R package (\code{RetHTS} dataset).
}
\keyword{datasets}
\keyword{histogram}
