% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interval_format_conversions.R
\name{int_list_conversions}
\alias{int_list_conversions}
\title{List Available Format Conversions}
\usage{
int_list_conversions(from = NULL, to = NULL)
}
\arguments{
\item{from}{source format (optional): "RSDA", "MM", "iGAP", "ARRAY", "SODAS"}

\item{to}{target format (optional): "RSDA", "MM", "iGAP", "ARRAY", "SODAS"}
}
\value{
A data.frame showing available conversions
}
\description{
List all available format conversion functions.
}
\examples{
# List all conversions
int_list_conversions()

# List conversions from RSDA
int_list_conversions(from = "RSDA")

# List conversions to MM
int_list_conversions(to = "MM")
}
