% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interval_stats.R
\name{interval_stats}
\alias{interval_stats}
\alias{int_mean}
\alias{int_var}
\alias{int_cov}
\alias{int_cor}
\title{Statistics for Interval Data}
\usage{
int_mean(x, var_name, method = "CM", ...)

int_var(x, var_name, method = "CM", ...)

int_cov(x, var_name1, var_name2, method = "CM", ...)

int_cor(x, var_name1, var_name2, method = "CM", ...)
}
\arguments{
\item{x}{interval-valued data with symbolic_tbl class.}

\item{var_name}{the variable name or the column location (multiple variables are allowed).}

\item{method}{methods to calculate statistics: CM (default), VM, QM, SE, FV, EJD, GQ, SPT.}

\item{...}{additional parameters}

\item{var_name1}{the variable name or the column location (multiple variables are allowed).}

\item{var_name2}{the variable name or the column location (multiple variables are allowed).}
}
\value{
A numeric matrix for \code{int_mean} and \code{int_var} (methods x variables);
  a named list of covariance/correlation matrices for \code{int_cov} and \code{int_cor}
  (one matrix per method).
}
\description{
Functions to compute the mean, variance, covariance, and correlation of interval-valued data.
}
\details{
Available methods (applicable to all four functions):
\itemize{
  \item \code{CM}: Center Method — uses midpoints (a + b) / 2
  \item \code{VM}: Vertices Method — uses all 2^p vertex combinations
  \item \code{QM}: Quantiles Method — uses equally spaced quantile points
  \item \code{SE}: Set Expansion — uses endpoints only (quantiles with m = 1)
  \item \code{FV}: Fitted Values — uses linear regression fitted values
  \item \code{EJD}: Empirical Joint Distribution
  \item \code{GQ}: Symbolic Covariance method (Billard and Diday, 2006)
  \item \code{SPT}: Total Sum of Products (Billard, 2008)
}
}
\examples{
data(mushroom.int)
int_mean(mushroom.int, var_name = "Pileus.Cap.Width")
int_mean(mushroom.int, var_name = 2:3)

var_name <- c("Stipe.Length", "Stipe.Thickness")
method <- c("CM", "FV", "EJD")
int_mean(mushroom.int, var_name, method)
int_var(mushroom.int, var_name, method)

var_name1 <- "Pileus.Cap.Width"
var_name2 <- c("Stipe.Length", "Stipe.Thickness")
method <- c("CM", "VM", "EJD", "GQ", "SPT")
int_cov(mushroom.int, var_name1, var_name2, method)
int_cor(mushroom.int, var_name1, var_name2, method)
}
\seealso{
int_mean int_var int_cov int_cor
}
\author{
Han-Ming Wu
}
