% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{hardwood.hist}
\alias{hardwood.hist}
\title{Hardwood Tree Species Histogram-Valued Dataset}
\format{
A data frame with 5 observations and 4 histogram-valued variables:
\itemize{
    \item \code{ANNT}: Annual temperature histogram (degrees C).
    \item \code{JULT}: July temperature histogram (degrees C).
    \item \code{ANNP}: Annual precipitation histogram (mm).
    \item \code{MITM}: Moisture index histogram.
}
}
\source{
Extracted from RSDA package (\code{hardwoodBrito}).
}
\usage{
data(hardwood.hist)
}
\description{
Histogram-valued climate data for 5 hardwood tree species in the
southeastern United States. Each observation represents a species with
4 histogram-valued climate variables.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 5 \cr
  \strong{Variables (p)} \tab 4 \cr
  \strong{Subject area} \tab Forestry \cr
  \strong{Symbolic format} \tab Histogram \cr
  \strong{Analytical tasks} \tab Clustering, Descriptive statistics
}
}

\examples{
data(hardwood.hist)
}
\references{
Brito, P. (2007). Modelling and Analysing Interval Data.
In V. Esposito Vinzi et al. (Eds.), \emph{New Developments in Classification
and Data Analysis}, pp. 197-208. Springer.
}
\keyword{datasets}
\keyword{histogram}
