% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{household_characteristics.distr}
\alias{household_characteristics.distr}
\title{Household Characteristics Distribution-Valued Dataset}
\format{
A data frame with 12 observations (counties) and 3
distribution-valued variables:
\itemize{
    \item \code{fuel_type}: Distribution over fuel types
          (gas, electric, oil, wood, none).
    \item \code{rooms}: Distribution over room counts
          (\{1,2\}, \{3,4,5\}, \{>=6\}).
    \item \code{household_income}: Distribution over income brackets
          (<10, [10,25), [25,50), [50,75), [75,100), [100,150), [150,200), >=200).
}
Row names are County_1 through County_12.
}
\source{
Billard, L. and Diday, E. (2020), Table 6-1.
}
\usage{
data(household_characteristics.distr)
}
\description{
Distribution-valued dataset of 12 counties with 3 categorical
probability distribution variables describing household fuel type,
number of rooms, and household income brackets.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 12 \cr
  \strong{Variables (p)} \tab 3 \cr
  \strong{Subject area} \tab Socioeconomics \cr
  \strong{Symbolic format} \tab Distribution \cr
  \strong{Analytical tasks} \tab Clustering, Descriptive statistics
}
}

\examples{
data(household_characteristics.distr)
}
\references{
Billard, L. and Diday, E. (2020). \emph{Clustering Methodology for
Symbolic Data}. Wiley, Chichester. Table 6-1.
}
\keyword{datasets}
\keyword{distribution}
\keyword{household}
