% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{lung_cancer.hist}
\alias{lung_cancer.hist}
\title{Lung Cancer Treatments by State Histogram-Valued Dataset}
\format{
A data frame with 2 observations and 2 variables:
\itemize{
    \item \code{state}: State name (character).
    \item \code{y30}: Histogram-valued distribution of treatment counts
          as a weighted set string (e.g., "\{0, 0.77; 1, 0.08; 2, 0.15\}").
}
}
\usage{
data(lung_cancer.hist)
}
\description{
Histogram-valued distribution of lung cancer treatment counts for 2 US
states (Massachusetts and New York).
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 2 \cr
  \strong{Variables (p)} \tab 2 \cr
  \strong{Subject area} \tab Medical \cr
  \strong{Symbolic format} \tab Histogram \cr
  \strong{Analytical tasks} \tab Descriptive statistics
}
}

\examples{
data(lung_cancer.hist)
}
\references{
Billard, L. and Diday, E. (2006). \emph{Symbolic Data Analysis}. Wiley.
Table 2.20.
}
\keyword{datasets}
\keyword{histogram}
