% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{loans_by_risk_quantile.int}
\alias{loans_by_risk_quantile.int}
\title{Lending Club Loans by Risk Level (Quantile-Based Intervals)}
\format{
A symbolic data frame (\code{symbolic_tbl}) with 35 observations
and 4 variables:
\itemize{
    \item \code{ln-inc}: Interval-valued log income.
    \item \code{int-rate}: Interval-valued interest rate.
    \item \code{open-acc}: Interval-valued number of open accounts.
    \item \code{total-acc}: Interval-valued total accounts.
}
}
\source{
MAINT.Data R package (\code{LoansbyRiskLvs_qntlDt} dataset).
}
\usage{
data(loans_by_risk_quantile.int)
}
\description{
Interval-valued dataset of 35 Lending Club loan groups stratified by risk
level (A1--G5). Intervals represent the 10th to 90th percentile range of
each financial variable within each risk subgrade.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 35 \cr
  \strong{Variables (p)} \tab 4 \cr
  \strong{Subject area} \tab Finance \cr
  \strong{Symbolic format} \tab Interval \cr
  \strong{Analytical tasks} \tab Classification, Clustering
}
}

\examples{
data(loans_by_risk_quantile.int)
}
\references{
Brito, P. and Duarte Silva, A.P. (2012). Modelling interval data with
Normal and Skew-Normal distributions. \emph{Journal of Applied Statistics},
39(1), 3--20.

Original data from the MAINT.Data R package
(\code{LoansbyRiskLvs_qntlDt} dataset).
}
\keyword{datasets}
\keyword{interval}
