% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{uscrime.int}
\alias{uscrime.int}
\title{US Crime Statistics Interval Dataset}
\format{
A symbolic data frame (\code{symbolic_tbl}) with 46 observations and
102 interval-valued variables. Key variables include:
\itemize{
    \item \code{fold}: Cross-validation fold assignment.
    \item \code{population}: Population range.
    \item \code{householdsize}: Household size range.
    \item \code{racepctblack}, \code{racePctWhite}, \code{racePctAsian},
          \code{racePctHisp}: Race percentage ranges.
    \item \code{medIncome}, \code{medFamInc}, \code{perCapInc}: Income ranges.
    \item \code{PctUnemployed}, \code{PctEmploy}: Employment percentage ranges.
    \item \code{ViolentCrimesPerPop}: Violent crimes per population range.
}
Plus 90 additional interval-valued socio-economic and demographic variables.
}
\source{
Extracted from RSDA package (\code{uscrime_int}).
}
\usage{
data(uscrime.int)
}
\description{
Interval-valued crime statistics for 46 US states, containing 102
interval-valued variables covering various crime types and rates.
Originally from the RSDA package.
}
\section{Metadata}{

\tabular{ll}{
  \strong{Sample size (n)} \tab 46 \cr
  \strong{Variables (p)} \tab 102 \cr
  \strong{Subject area} \tab Criminology \cr
  \strong{Symbolic format} \tab Interval \cr
  \strong{Analytical tasks} \tab Regression, Clustering
}
}

\examples{
data(uscrime.int)
}
\references{
Rodriguez, O. (2000). Classification et modeles lineaires en analyse
des donnees symboliques. Doctoral Thesis, Universite Paris IX-Dauphine.
}
\keyword{crime}
\keyword{datasets}
\keyword{interval}
